@@ -26,13 +26,15 @@ __date__      = "$Date$"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
+import os
+
 # $ORCA_VERSION
 #
-version     = "45.2"
+version     = "46.0"
 
 # The revision if built from git; otherwise an empty string
 #
-revision = "cd1c1f25f"
+revision = "4819fd6bf"
 
 # "--prefix" parameter used when configuring the build.
 #
@@ -44,7 +46,7 @@ package     = "orca"
 
 # The location of the data directory (usually "share").
 #
-datadir = "${prefix}/share".replace('${prefix}', '/usr')
+datadir = os.path.join('/usr','share')
 
 # The directory where we could find liblouis translation tables.
 #
